@@ -55,7 +55,7 @@ from validation_results import *
 import command
 import parse_requirements
 from find_module import find_python_module
-from engage_django_components import validate_django_components
+from engage_django_components import COMPONENTS_FILENAME, read_components_file
 from package_data import PREINSTALLED_PACKAGES, get_apps_for_packages, \
      PACKAGES_FOR_KNOWN_APPS
 
@@ -83,6 +83,16 @@ def run_safe_validations(handler):
     data = fileobj.read()
     django_config = django_config_from_json(data, COMPATIBLE_PACKAGER_VERSION)
 
+    # check for additional_components file and parse if present
+    components_file = common_dir + os.sep + COMPONENTS_FILENAME
+    if handler.is_file_in_archive(components_file):
+        fileobj = handler.open_member(components_file)
+        read_components_file(fileobj, components_file, django_config.components)
+    else:
+        if len(django_config.components)>0:
+            raise ValidationError("No additional component file at %s, but application with packaged with an additional component file" %
+                                  filepath)
+
     # check for other required files
     settings_module_file = django_config.get_settings_module_file()
     if not handler.is_file_in_archive(settings_module_file):
@@ -416,10 +426,11 @@ def validate_settings(app_dir_path, django_settings_module, django_config=None,
     else:
         results.post_install_commands = []
 
-    # check ENGAGE_DJANGO_COMPONENTS
-    if hasattr(settings_module, "ENGAGE_DJANGO_COMPONENTS"):
-        validate_django_components(settings_module.ENGAGE_DJANGO_COMPONENTS,
-                                   prev_version_component_list, results)
+    # read the additional components file and put the data into the results
+    additional_comp_file = os.path.join(app_dir_path, COMPONENTS_FILENAME)
+    if os.path.exists(additional_comp_file):
+        with open(additional_comp_file, "rb") as cf:
+            results.components = read_components_file(cf, additional_comp_file, None)
     else:
         results.components = []
         
