@@ -8,10 +8,12 @@ import re
 import subprocess
 import traceback
 import logging
+import copy
 
 logger = logging.getLogger(__name__)
 
-from parse_requirements import parse
+from parse_requirements import parse,  get_local_files_matching_requirements
+from engage_django_components import get_additional_requirements
 
 def app_module_name_to_dir(app_directory_path, app_module_name, check_for_init_pys=True):
     """The application module could be a submodule, so we may need to split each level"""
@@ -100,12 +102,6 @@ def run_and_log_program(program_and_args, env_mapping, logger, cwd=None,
     logger.debug(' '.join(program_and_args))
     if cwd != None:
         logger.debug("Subprocess working directory is %s" % cwd)
-    if env_mapping == None:
-        logger.debug("Subprocess inheriting parent process's environment")
-    elif len(env_mapping)>0:
-        logger.debug("Subprocess environment is %s" % env_mapping.__str__())
-    else:
-        logger.debug("Subprocess passed empty environment")
     subproc = subprocess.Popen(program_and_args,
                                env=env_mapping, stdin=subprocess.PIPE,
                                stdout=subprocess.PIPE,
@@ -190,10 +186,6 @@ def create_virtualenv(desired_python_dir):
         logger.exception("Problem in creating virtualenv. Command was '%s', error was %s" % (' '.join(cmd), str(e)))
         raise Exception("Problem in creating virtualenv. Command was '%s', error was %s" % (' '.join(cmd), str(e)))
 
-packages_to_files = {
-    "Django": "Django-1.2.5.tar.gz",
-    "South": "South-0.7.3.tar.gz",  
-}
 
 def install_requirements(python_virtualenv_dir, requirements_file,
                          package_cache_dir=None):
@@ -210,34 +202,50 @@ def install_requirements(python_virtualenv_dir, requirements_file,
         # match them.
         package_cache_dir = os.path.abspath(os.path.expanduser(package_cache_dir))
         logger.debug("Checking for packages in directory %s" % package_cache_dir)
-        packages = parse(req_file_path)
-        for package in packages:
-            if packages_to_files.has_key(package):
-                pkg_file = os.path.join(package_cache_dir, packages_to_files[package])
-                if os.path.exists(pkg_file):
-                    cmd = [pip, "install", pkg_file]
-                    try:
-                        check_run_and_log_program(cmd, None, logger)
-                    except Exception, e:
-                        logger.exception("Problem in running pip on package %s. Command was '%s', error was %s" % (pkg_file, ' '.join(cmd), str(e)))
-                        raise Exception("Problem in running pip on package %s. Command was '%s', error was %s" % (pkg_file, ' '.join(cmd), str(e)))
-                        
+        if os.path.exists(package_cache_dir):
+            cache_files = os.listdir(package_cache_dir)
+            package_files = get_local_files_matching_requirements(requirements_file,
+                                                                  cache_files)
+            for pkg_file in package_files:
+                pkg_path = os.path.join(package_cache_dir, pkg_file)
+                logger.debug("Installing %s from package cache" % pkg_file)
+                cmd = [pip, "install", pkg_path]
+                try:
+                    check_run_and_log_program(cmd, None, logger)
+                except Exception, e:
+                    logger.exception("Problem in running pip on package %s. Command was '%s', error was %s" % (pkg_file, ' '.join(cmd), str(e)))
+                    raise Exception("Problem in running pip on package %s. Command was '%s', error was %s" % (pkg_file, ' '.join(cmd), str(e)))
+
     # now, run pip on the requirements file.  
     cmd = [pip, "install", "-r", req_file_path]
+    env = copy.deepcopy(os.environ)
+    if package_cache_dir:
+        env["PIP_DOWNLOAD_CACHE"] = package_cache_dir
     try:
-        check_run_and_log_program(cmd, None, logger)
+        check_run_and_log_program(cmd, env, logger)
     except Exception, e:
         logger.exception("Problem in running pip on requirements file. Command was '%s', error was %s" % (' '.join(cmd), str(e)))
         raise Exception("Problem in running pip on requirements file. Command was '%s', error was %s" % (' '.join(cmd), str(e)))
 
-_platform_requirements = """
-# engage platform requirements
-Django==1.2.5
-South==0.7.3
-"""
+_platform_requirements = [
+  "Django==1.2.5",
+  "South==0.7.3"
+]
 
-def write_platform_requirements_file(parent_dir):
-    requirements_file = os.path.abspath(os.path.join(os.path.expanduser(parent_dir), "engage_requirements.txt"))
+def write_platform_requirements_file(install_path, components_list):
+    requirements = copy.copy(_platform_requirements)
+    req_set = set(requirements)
+    # we stick the requirements file one level above the project root
+    requirements_file = os.path.join(install_path, "engage_requirements.txt")
+    for comp in components_list:
+        req_list = get_additional_requirements(comp)
+        for req in req_list:
+            if req not in req_set:
+                requirements.append(req)
+                req_set.add(req)
+    logger.debug("Platform requirements: %s" % requirements)
     with open(requirements_file, "w") as f:
-        f.write(_platform_requirements)
+        f.write("# Engage platform requirements\n")
+        for req in requirements:
+            f.write(req + "\n")
     return requirements_file
